@@ -17,7 +17,7 @@ use App::VTide::Hooks;
 use Path::Tiny;
 use YAML::Syck qw/ LoadFile DumpFile /;
 
-our $VERSION = version->new('0.1.19');
+our $VERSION = version->new('0.1.20');
 
 has config => (
     is      => 'rw',
@@ -42,7 +42,7 @@ sub run {
 
     my ( $options, $cmd, $opt ) = get_options(
         {
-            name          => 'vtide',
+            name          => 'vtide-cmd',
             conf_prefix   => '.',
             helper        => 1,
             default       => { test => 0, },
@@ -127,7 +127,15 @@ sub run {
         unshift @{ $opt->files }, $opt->cmd;
     }
 
-    return $subcommand->run;
+    eval {
+        $subcommand->run;
+        1;
+    } or do {
+        warn "Error running " . $opt->cmd . "!\n";
+        warn $@;
+        sleep 5;
+    };
+    return;
 }
 
 sub load_subcommand {
@@ -192,12 +200,15 @@ App::VTide - A vim/tmux based IDE for the terminal
 
 =head1 VERSION
 
-This documentation refers to App::VTide version 0.1.19
+This documentation refers to App::VTide version 0.1.20
 
 =head1 SYNOPSIS
 
+  Session level
+    vtide init
     vtide [start] [project]
-    vtide (init|start|edit|run|conf|grep|recent|split|refresh|save|help) [options]
+  With in a session
+    vtide (edit|run|conf|grep|recent|split|refresh|save|help) [options]
 
   COMMANDS:
     conf    Show editor config settings
